@@ -7,13 +7,13 @@ use reqwest::{
     header::{HeaderMap, AUTHORIZATION, USER_AGENT},
     StatusCode, Url,
 };
-use sodiumoxide::crypto::secretbox;
 
 use atuin_common::api::{
     AddHistoryRequest, CountResponse, DeleteHistoryRequest, ErrorResponse, IndexResponse,
     LoginRequest, LoginResponse, RegisterResponse, StatusResponse, SyncHistoryResponse,
 };
 use semver::Version;
+use xsalsa20poly1305::Key;
 
 use crate::{
     encryption::{decode_key, decrypt},
@@ -28,7 +28,7 @@ static APP_USER_AGENT: &str = concat!("atuin/", env!("CARGO_PKG_VERSION"),);
 
 pub struct Client<'a> {
     sync_addr: &'a str,
-    key: secretbox::Key,
+    key: Key,
     client: reqwest::Client,
 }
 
@@ -182,7 +182,7 @@ impl<'a> Client<'a> {
             .iter()
             // TODO: handle deletion earlier in this chain
             .map(|h| serde_json::from_str(h).expect("invalid base64"))
-            .map(|h| decrypt(&h, &self.key).expect("failed to decrypt history! check your key"))
+            .map(|h| decrypt(h, &self.key).expect("failed to decrypt history! check your key"))
             .map(|mut h| {
                 if deleted.contains(&h.id) {
                     h.deleted_at = Some(chrono::Utc::now());
@@ -217,4 +217,19 @@ impl<'a> Client<'a> {
 
         Ok(())
     }
+
+    pub async fn delete(&self) -> Result<()> {
+        let url = format!("{}/account", self.sync_addr);
+        let url = Url::parse(url.as_str())?;
+
+        let resp = self.client.delete(url).send().await?;
+
+        if resp.status() == 403 {
+            bail!("invalid login details");
+        } else if resp.status() == 200 {
+            Ok(())
+        } else {
+            bail!("Unknown error");
+        }
+    }
 }
