@@ -15,6 +15,7 @@ pub struct Settings {
     pub db_uri: String,
     pub open_registration: bool,
     pub max_history_length: usize,
+    pub page_size: i64,
     pub register_webhook_url: Option<String>,
     pub register_webhook_username: String,
 }
@@ -40,6 +41,7 @@ impl Settings {
             .set_default("max_history_length", 8192)?
             .set_default("path", "")?
             .set_default("register_webhook_username", "")?
+            .set_default("page_size", 1100)?
             .add_source(
                 Environment::with_prefix("atuin")
                     .prefix_separator("_")
